# Multiclass pixel classifier
Deep learning segmentation method with very low annotation requirement.

Similar to [Ilastik pixel classification](https://www.ilastik.org/documentation/pixelclassification/pixelclassification) procedure, but based on a deep neural network.

Described and used in the work [Near-infrared co-illumination of fluorescent proteins reduces photobleaching and phototoxicity](https://doi.org/10.1038/s41587-023-01893-7). Please cite this work when using this method. 

Docuementation: see this [tutorial](https://github.com/jeanollion/bacmman/wiki/Train-and-use-PixMClass)
